package fr.velossity.sample.device.impl;

import fr.velossity.sample.device.Device;
import fr.velossity.sample.device.Measurement;

/**
 * A simple consumer displaying a device measurements.
 * @author C. Saint-Marcel
 * 
 */
public class Consumer implements Runnable {

	/**
	 * Thread.
	 */
	private Thread measureGetter;	
	
	/**
	 * iPOJO injected field.
	 */
	private Device myDevice;

	/**
	 * iPOJO Callback.
	 */
	public void activate() {
		if(measureGetter == null) {
			measureGetter = new Thread(this);
			measureGetter.start();
		}

	}

	/**
	 */
	public void deactivate() {
		measureGetter = null;
	}
	
	/**
	 * @see Runnable#run()
	 */
	public void run() {
		Thread mg = measureGetter;
		while (measureGetter == mg) {
			// INVOKES the service
			newMeasure(myDevice.getLastMeasure());
			try {
				synchronized (this) {
					wait(10000);	
				}				
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
		}
	}

	/**
	 * Just echoing the measurement to the console.
	 */
	private void newMeasure(final Measurement measurement) {
		if(measurement != null) { // It can be null if the Producer service is declared before setting the measurement
			System.out.println("New measure [" + measurement.getSource().getIdentifier() + "]= " + measurement.getValue() + " " + measurement.getUnit());
		}
	}
}
